Molten Document
molten-document provides document schema definitions, field types, validation, and
document management functionality for the Molten Document and Workflow Management system.
This crate is under active development and is not yet stable. If this crate has been abandoned, please message me and we can discuss ownership transfer.
Re-exports
pub use error::DocumentValidationError;pub use validator::validate_document;